If the name is not provided in the request, the server will assign a random name for this * subscription on the same project as the topic, conforming to the [resource name format] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated name is populated in - * the returned Subscription object. Note that for REST API requests, you must specify a name in - * the request. + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The generated name is + * populated in the returned Subscription object. Note that for REST API requests, you must + * specify a name in the request. * *
Sample code: * @@ -292,15 +292,15 @@ public final Subscription createSubscription( // AUTO-GENERATED DOCUMENTATION AND METHOD. /** * Creates a subscription to a given topic. See the [resource name rules] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). If the subscription already - * exists, returns `ALREADY_EXISTS`. If the corresponding topic doesn't exist, returns + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). If the subscription + * already exists, returns `ALREADY_EXISTS`. If the corresponding topic doesn't exist, returns * `NOT_FOUND`. * *
If the name is not provided in the request, the server will assign a random name for this * subscription on the same project as the topic, conforming to the [resource name format] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated name is populated in - * the returned Subscription object. Note that for REST API requests, you must specify a name in - * the request. + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The generated name is + * populated in the returned Subscription object. Note that for REST API requests, you must + * specify a name in the request. * *
Sample code: * @@ -362,15 +362,15 @@ public final Subscription createSubscription( // AUTO-GENERATED DOCUMENTATION AND METHOD. /** * Creates a subscription to a given topic. See the [resource name rules] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). If the subscription already - * exists, returns `ALREADY_EXISTS`. If the corresponding topic doesn't exist, returns + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). If the subscription + * already exists, returns `ALREADY_EXISTS`. If the corresponding topic doesn't exist, returns * `NOT_FOUND`. * *
If the name is not provided in the request, the server will assign a random name for this * subscription on the same project as the topic, conforming to the [resource name format] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated name is populated in - * the returned Subscription object. Note that for REST API requests, you must specify a name in - * the request. + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The generated name is + * populated in the returned Subscription object. Note that for REST API requests, you must + * specify a name in the request. * *
Sample code: * @@ -432,15 +432,15 @@ public final Subscription createSubscription( // AUTO-GENERATED DOCUMENTATION AND METHOD. /** * Creates a subscription to a given topic. See the [resource name rules] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). If the subscription already - * exists, returns `ALREADY_EXISTS`. If the corresponding topic doesn't exist, returns + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). If the subscription + * already exists, returns `ALREADY_EXISTS`. If the corresponding topic doesn't exist, returns * `NOT_FOUND`. * *
If the name is not provided in the request, the server will assign a random name for this * subscription on the same project as the topic, conforming to the [resource name format] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated name is populated in - * the returned Subscription object. Note that for REST API requests, you must specify a name in - * the request. + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The generated name is + * populated in the returned Subscription object. Note that for REST API requests, you must + * specify a name in the request. * *
Sample code: * @@ -502,15 +502,15 @@ public final Subscription createSubscription( // AUTO-GENERATED DOCUMENTATION AND METHOD. /** * Creates a subscription to a given topic. See the [resource name rules] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). If the subscription already - * exists, returns `ALREADY_EXISTS`. If the corresponding topic doesn't exist, returns + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). If the subscription + * already exists, returns `ALREADY_EXISTS`. If the corresponding topic doesn't exist, returns * `NOT_FOUND`. * *
If the name is not provided in the request, the server will assign a random name for this * subscription on the same project as the topic, conforming to the [resource name format] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated name is populated in - * the returned Subscription object. Note that for REST API requests, you must specify a name in - * the request. + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The generated name is + * populated in the returned Subscription object. Note that for REST API requests, you must + * specify a name in the request. * *
Sample code: * @@ -765,15 +765,15 @@ public final Subscription createSubscription( // AUTO-GENERATED DOCUMENTATION AND METHOD. /** * Creates a subscription to a given topic. See the [resource name rules] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). If the subscription already - * exists, returns `ALREADY_EXISTS`. If the corresponding topic doesn't exist, returns + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). If the subscription + * already exists, returns `ALREADY_EXISTS`. If the corresponding topic doesn't exist, returns * `NOT_FOUND`. * *
If the name is not provided in the request, the server will assign a random name for this * subscription on the same project as the topic, conforming to the [resource name format] - * (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated name is populated in - * the returned Subscription object. Note that for REST API requests, you must specify a name in - * the request. + * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The generated name is + * populated in the returned Subscription object. Note that for REST API requests, you must + * specify a name in the request. * *
Sample code:
*
@@ -2609,9 +2609,9 @@ public final UnaryCallable Sample code:
*
@@ -2631,7 +2631,7 @@ public final UnaryCallable Sample code:
*
@@ -2684,7 +2684,7 @@ public final Snapshot createSnapshot(SnapshotName name, SubscriptionName subscri
* @param name Required. User-provided name for this snapshot. If the name is not provided in the
* request, the server will assign a random name for this snapshot on the same project as the
* subscription. Note that for REST API requests, you must specify a name. See the [resource
- * name rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format is
+ * name rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). Format is
* `projects/{project}/snapshots/{snap}`.
* @param subscription Required. The subscription whose backlog the snapshot retains.
* Specifically, the created snapshot is guaranteed to retain: (a) The existing backlog on the
@@ -2715,9 +2715,9 @@ public final Snapshot createSnapshot(SnapshotName name, String subscription) {
* expire in less than 1 hour -- then `FAILED_PRECONDITION` is returned. See also the
* `Snapshot.expire_time` field. If the name is not provided in the request, the server will
* assign a random name for this snapshot on the same project as the subscription, conforming to
- * the [resource name format] (https://cloud.google.com/pubsub/docs/admin#resource_names). The
- * generated name is populated in the returned Snapshot object. Note that for REST API requests,
- * you must specify a name in the request.
+ * the [resource name format] (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * The generated name is populated in the returned Snapshot object. Note that for REST API
+ * requests, you must specify a name in the request.
*
* Sample code:
*
@@ -2737,7 +2737,7 @@ public final Snapshot createSnapshot(SnapshotName name, String subscription) {
* @param name Required. User-provided name for this snapshot. If the name is not provided in the
* request, the server will assign a random name for this snapshot on the same project as the
* subscription. Note that for REST API requests, you must specify a name. See the [resource
- * name rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format is
+ * name rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). Format is
* `projects/{project}/snapshots/{snap}`.
* @param subscription Required. The subscription whose backlog the snapshot retains.
* Specifically, the created snapshot is guaranteed to retain: (a) The existing backlog on the
@@ -2768,9 +2768,9 @@ public final Snapshot createSnapshot(String name, SubscriptionName subscription)
* expire in less than 1 hour -- then `FAILED_PRECONDITION` is returned. See also the
* `Snapshot.expire_time` field. If the name is not provided in the request, the server will
* assign a random name for this snapshot on the same project as the subscription, conforming to
- * the [resource name format] (https://cloud.google.com/pubsub/docs/admin#resource_names). The
- * generated name is populated in the returned Snapshot object. Note that for REST API requests,
- * you must specify a name in the request.
+ * the [resource name format] (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * The generated name is populated in the returned Snapshot object. Note that for REST API
+ * requests, you must specify a name in the request.
*
* Sample code:
*
@@ -2790,7 +2790,7 @@ public final Snapshot createSnapshot(String name, SubscriptionName subscription)
* @param name Required. User-provided name for this snapshot. If the name is not provided in the
* request, the server will assign a random name for this snapshot on the same project as the
* subscription. Note that for REST API requests, you must specify a name. See the [resource
- * name rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format is
+ * name rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). Format is
* `projects/{project}/snapshots/{snap}`.
* @param subscription Required. The subscription whose backlog the snapshot retains.
* Specifically, the created snapshot is guaranteed to retain: (a) The existing backlog on the
@@ -2818,9 +2818,9 @@ public final Snapshot createSnapshot(String name, String subscription) {
* expire in less than 1 hour -- then `FAILED_PRECONDITION` is returned. See also the
* `Snapshot.expire_time` field. If the name is not provided in the request, the server will
* assign a random name for this snapshot on the same project as the subscription, conforming to
- * the [resource name format] (https://cloud.google.com/pubsub/docs/admin#resource_names). The
- * generated name is populated in the returned Snapshot object. Note that for REST API requests,
- * you must specify a name in the request.
+ * the [resource name format] (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * The generated name is populated in the returned Snapshot object. Note that for REST API
+ * requests, you must specify a name in the request.
*
* Sample code:
*
@@ -3010,9 +3010,9 @@ public final Snapshot createSnapshot(ProjectSnapshotName name, String subscripti
* expire in less than 1 hour -- then `FAILED_PRECONDITION` is returned. See also the
* `Snapshot.expire_time` field. If the name is not provided in the request, the server will
* assign a random name for this snapshot on the same project as the subscription, conforming to
- * the [resource name format] (https://cloud.google.com/pubsub/docs/admin#resource_names). The
- * generated name is populated in the returned Snapshot object. Note that for REST API requests,
- * you must specify a name in the request.
+ * the [resource name format] (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * The generated name is populated in the returned Snapshot object. Note that for REST API
+ * requests, you must specify a name in the request.
*
* Sample code:
*
diff --git a/google-cloud-pubsub/src/main/java/com/google/cloud/pubsub/v1/TopicAdminClient.java b/google-cloud-pubsub/src/main/java/com/google/cloud/pubsub/v1/TopicAdminClient.java
index 80a3b3fa4..b1f0dc35f 100644
--- a/google-cloud-pubsub/src/main/java/com/google/cloud/pubsub/v1/TopicAdminClient.java
+++ b/google-cloud-pubsub/src/main/java/com/google/cloud/pubsub/v1/TopicAdminClient.java
@@ -197,7 +197,7 @@ public PublisherStub getStub() {
// AUTO-GENERATED DOCUMENTATION AND METHOD.
/**
* Creates the given topic with the given name. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
*
* Sample code:
*
@@ -228,7 +228,7 @@ public final Topic createTopic(TopicName name) {
// AUTO-GENERATED DOCUMENTATION AND METHOD.
/**
* Creates the given topic with the given name. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
*
* Sample code:
*
@@ -288,7 +288,7 @@ public final Topic createTopic(ProjectTopicName name) {
// AUTO-GENERATED DOCUMENTATION AND METHOD.
/**
* Creates the given topic with the given name. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
*
* Sample code:
*
@@ -323,7 +323,7 @@ public final Topic createTopic(Topic request) {
// AUTO-GENERATED DOCUMENTATION AND METHOD.
/**
* Creates the given topic with the given name. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
*
* Sample code:
*
diff --git a/google-cloud-pubsub/src/main/java/com/google/cloud/pubsub/v1/stub/PublisherStubSettings.java b/google-cloud-pubsub/src/main/java/com/google/cloud/pubsub/v1/stub/PublisherStubSettings.java
index 16cdef839..73510eee0 100644
--- a/google-cloud-pubsub/src/main/java/com/google/cloud/pubsub/v1/stub/PublisherStubSettings.java
+++ b/google-cloud-pubsub/src/main/java/com/google/cloud/pubsub/v1/stub/PublisherStubSettings.java
@@ -654,7 +654,7 @@ public static class Builder extends StubSettings.Builder
* Creates the given topic with the given name. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
*
*/
default void createTopic(
@@ -640,7 +640,7 @@ protected PublisherStub build(io.grpc.Channel channel, io.grpc.CallOptions callO
*
*
* Creates the given topic with the given name. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
*
*/
public void createTopic(
@@ -816,7 +816,7 @@ protected PublisherBlockingStub build(
*
*
* Creates the given topic with the given name. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
*
*/
public com.google.pubsub.v1.Topic createTopic(com.google.pubsub.v1.Topic request) {
@@ -963,7 +963,7 @@ protected PublisherFutureStub build(io.grpc.Channel channel, io.grpc.CallOptions
*
*
* Creates the given topic with the given name. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
*
*/
public com.google.common.util.concurrent.ListenableFuture
* Creates a subscription to a given topic. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
* If the subscription already exists, returns `ALREADY_EXISTS`.
* If the corresponding topic doesn't exist, returns `NOT_FOUND`.
* If the name is not provided in the request, the server will assign a random
* name for this subscription on the same project as the topic, conforming
* to the [resource name format]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated
- * name is populated in the returned Subscription object. Note that for REST
- * API requests, you must specify a name in the request.
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The
+ * generated name is populated in the returned Subscription object. Note that
+ * for REST API requests, you must specify a name in the request.
*
*/
default void createSubscription(
@@ -962,7 +962,7 @@ default void listSnapshots(
* the request, the server will assign a random
* name for this snapshot on the same project as the subscription, conforming
* to the [resource name format]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names). The
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The
* generated name is populated in the returned Snapshot object. Note that for
* REST API requests, you must specify a name in the request.
*
@@ -1075,15 +1075,15 @@ protected SubscriberStub build(io.grpc.Channel channel, io.grpc.CallOptions call
*
*
* Creates a subscription to a given topic. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
* If the subscription already exists, returns `ALREADY_EXISTS`.
* If the corresponding topic doesn't exist, returns `NOT_FOUND`.
* If the name is not provided in the request, the server will assign a random
* name for this subscription on the same project as the topic, conforming
* to the [resource name format]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated
- * name is populated in the returned Subscription object. Note that for REST
- * API requests, you must specify a name in the request.
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The
+ * generated name is populated in the returned Subscription object. Note that
+ * for REST API requests, you must specify a name in the request.
*
*/
public void createSubscription(
@@ -1316,7 +1316,7 @@ public void listSnapshots(
* the request, the server will assign a random
* name for this snapshot on the same project as the subscription, conforming
* to the [resource name format]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names). The
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The
* generated name is populated in the returned Snapshot object. Note that for
* REST API requests, you must specify a name in the request.
*
@@ -1421,15 +1421,15 @@ protected SubscriberBlockingStub build(
*
*
* Creates a subscription to a given topic. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
* If the subscription already exists, returns `ALREADY_EXISTS`.
* If the corresponding topic doesn't exist, returns `NOT_FOUND`.
* If the name is not provided in the request, the server will assign a random
* name for this subscription on the same project as the topic, conforming
* to the [resource name format]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated
- * name is populated in the returned Subscription object. Note that for REST
- * API requests, you must specify a name in the request.
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The
+ * generated name is populated in the returned Subscription object. Note that
+ * for REST API requests, you must specify a name in the request.
*
*/
public com.google.pubsub.v1.Subscription createSubscription(
@@ -1609,7 +1609,7 @@ public com.google.pubsub.v1.ListSnapshotsResponse listSnapshots(
* the request, the server will assign a random
* name for this snapshot on the same project as the subscription, conforming
* to the [resource name format]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names). The
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The
* generated name is populated in the returned Snapshot object. Note that for
* REST API requests, you must specify a name in the request.
*
@@ -1702,15 +1702,15 @@ protected SubscriberFutureStub build(io.grpc.Channel channel, io.grpc.CallOption
*
*
* Creates a subscription to a given topic. See the [resource name rules]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
* If the subscription already exists, returns `ALREADY_EXISTS`.
* If the corresponding topic doesn't exist, returns `NOT_FOUND`.
* If the name is not provided in the request, the server will assign a random
* name for this subscription on the same project as the topic, conforming
* to the [resource name format]
- * (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated
- * name is populated in the returned Subscription object. Note that for REST
- * API requests, you must specify a name in the request.
+ * (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The
+ * generated name is populated in the returned Subscription object. Note that
+ * for REST API requests, you must specify a name in the request.
*
*/
public com.google.common.util.concurrent.ListenableFuture
- * When true, use the topic's schema as the columns to write to in BigQuery,
- * if it exists.
+ * Optional. When true, use the topic's schema as the columns to write to in
+ * BigQuery, if it exists. `use_topic_schema` and `use_table_schema` cannot be
+ * enabled at the same time.
*
*
- * bool use_topic_schema = 2;
+ * bool use_topic_schema = 2 [(.google.api.field_behavior) = OPTIONAL];
*
* @return The useTopicSchema.
*/
@@ -431,6 +432,26 @@ public com.google.pubsub.v1.BigQueryConfig.State getState() {
return result == null ? com.google.pubsub.v1.BigQueryConfig.State.UNRECOGNIZED : result;
}
+ public static final int USE_TABLE_SCHEMA_FIELD_NUMBER = 6;
+ private boolean useTableSchema_ = false;
+ /**
+ *
+ *
+ *
+ * Optional. When true, use the BigQuery table's schema as the columns to
+ * write to in BigQuery. `use_table_schema` and `use_topic_schema` cannot be
+ * enabled at the same time.
+ *
+ *
+ * bool use_table_schema = 6 [(.google.api.field_behavior) = OPTIONAL];
+ *
+ * @return The useTableSchema.
+ */
+ @java.lang.Override
+ public boolean getUseTableSchema() {
+ return useTableSchema_;
+ }
+
private byte memoizedIsInitialized = -1;
@java.lang.Override
@@ -460,6 +481,9 @@ public void writeTo(com.google.protobuf.CodedOutputStream output) throws java.io
if (state_ != com.google.pubsub.v1.BigQueryConfig.State.STATE_UNSPECIFIED.getNumber()) {
output.writeEnum(5, state_);
}
+ if (useTableSchema_ != false) {
+ output.writeBool(6, useTableSchema_);
+ }
getUnknownFields().writeTo(output);
}
@@ -484,6 +508,9 @@ public int getSerializedSize() {
if (state_ != com.google.pubsub.v1.BigQueryConfig.State.STATE_UNSPECIFIED.getNumber()) {
size += com.google.protobuf.CodedOutputStream.computeEnumSize(5, state_);
}
+ if (useTableSchema_ != false) {
+ size += com.google.protobuf.CodedOutputStream.computeBoolSize(6, useTableSchema_);
+ }
size += getUnknownFields().getSerializedSize();
memoizedSize = size;
return size;
@@ -504,6 +531,7 @@ public boolean equals(final java.lang.Object obj) {
if (getWriteMetadata() != other.getWriteMetadata()) return false;
if (getDropUnknownFields() != other.getDropUnknownFields()) return false;
if (state_ != other.state_) return false;
+ if (getUseTableSchema() != other.getUseTableSchema()) return false;
if (!getUnknownFields().equals(other.getUnknownFields())) return false;
return true;
}
@@ -525,6 +553,8 @@ public int hashCode() {
hash = (53 * hash) + com.google.protobuf.Internal.hashBoolean(getDropUnknownFields());
hash = (37 * hash) + STATE_FIELD_NUMBER;
hash = (53 * hash) + state_;
+ hash = (37 * hash) + USE_TABLE_SCHEMA_FIELD_NUMBER;
+ hash = (53 * hash) + com.google.protobuf.Internal.hashBoolean(getUseTableSchema());
hash = (29 * hash) + getUnknownFields().hashCode();
memoizedHashCode = hash;
return hash;
@@ -668,6 +698,7 @@ public Builder clear() {
writeMetadata_ = false;
dropUnknownFields_ = false;
state_ = 0;
+ useTableSchema_ = false;
return this;
}
@@ -718,6 +749,9 @@ private void buildPartial0(com.google.pubsub.v1.BigQueryConfig result) {
if (((from_bitField0_ & 0x00000010) != 0)) {
result.state_ = state_;
}
+ if (((from_bitField0_ & 0x00000020) != 0)) {
+ result.useTableSchema_ = useTableSchema_;
+ }
}
@java.lang.Override
@@ -782,6 +816,9 @@ public Builder mergeFrom(com.google.pubsub.v1.BigQueryConfig other) {
if (other.state_ != 0) {
setStateValue(other.getStateValue());
}
+ if (other.getUseTableSchema() != false) {
+ setUseTableSchema(other.getUseTableSchema());
+ }
this.mergeUnknownFields(other.getUnknownFields());
onChanged();
return this;
@@ -838,6 +875,12 @@ public Builder mergeFrom(
bitField0_ |= 0x00000010;
break;
} // case 40
+ case 48:
+ {
+ useTableSchema_ = input.readBool();
+ bitField0_ |= 0x00000020;
+ break;
+ } // case 48
default:
{
if (!super.parseUnknownField(input, extensionRegistry, tag)) {
@@ -973,11 +1016,12 @@ public Builder setTableBytes(com.google.protobuf.ByteString value) {
*
*
*
- * When true, use the topic's schema as the columns to write to in BigQuery,
- * if it exists.
+ * Optional. When true, use the topic's schema as the columns to write to in
+ * BigQuery, if it exists. `use_topic_schema` and `use_table_schema` cannot be
+ * enabled at the same time.
*
*
- * bool use_topic_schema = 2;
+ * bool use_topic_schema = 2 [(.google.api.field_behavior) = OPTIONAL];
*
* @return The useTopicSchema.
*/
@@ -989,11 +1033,12 @@ public boolean getUseTopicSchema() {
*
*
*
- * When true, use the topic's schema as the columns to write to in BigQuery,
- * if it exists.
+ * Optional. When true, use the topic's schema as the columns to write to in
+ * BigQuery, if it exists. `use_topic_schema` and `use_table_schema` cannot be
+ * enabled at the same time.
*
*
- * bool use_topic_schema = 2;
+ * bool use_topic_schema = 2 [(.google.api.field_behavior) = OPTIONAL];
*
* @param value The useTopicSchema to set.
* @return This builder for chaining.
@@ -1009,11 +1054,12 @@ public Builder setUseTopicSchema(boolean value) {
*
*
*
- * When true, use the topic's schema as the columns to write to in BigQuery,
- * if it exists.
+ * Optional. When true, use the topic's schema as the columns to write to in
+ * BigQuery, if it exists. `use_topic_schema` and `use_table_schema` cannot be
+ * enabled at the same time.
*
*
- * bool use_topic_schema = 2;
+ * bool use_topic_schema = 2 [(.google.api.field_behavior) = OPTIONAL];
*
* @return This builder for chaining.
*/
@@ -1259,6 +1305,65 @@ public Builder clearState() {
return this;
}
+ private boolean useTableSchema_;
+ /**
+ *
+ *
+ *
+ * Optional. When true, use the BigQuery table's schema as the columns to
+ * write to in BigQuery. `use_table_schema` and `use_topic_schema` cannot be
+ * enabled at the same time.
+ *
+ *
+ * bool use_table_schema = 6 [(.google.api.field_behavior) = OPTIONAL];
+ *
+ * @return The useTableSchema.
+ */
+ @java.lang.Override
+ public boolean getUseTableSchema() {
+ return useTableSchema_;
+ }
+ /**
+ *
+ *
+ *
+ * Optional. When true, use the BigQuery table's schema as the columns to
+ * write to in BigQuery. `use_table_schema` and `use_topic_schema` cannot be
+ * enabled at the same time.
+ *
+ *
+ * bool use_table_schema = 6 [(.google.api.field_behavior) = OPTIONAL];
+ *
+ * @param value The useTableSchema to set.
+ * @return This builder for chaining.
+ */
+ public Builder setUseTableSchema(boolean value) {
+
+ useTableSchema_ = value;
+ bitField0_ |= 0x00000020;
+ onChanged();
+ return this;
+ }
+ /**
+ *
+ *
+ *
+ * Optional. When true, use the BigQuery table's schema as the columns to
+ * write to in BigQuery. `use_table_schema` and `use_topic_schema` cannot be
+ * enabled at the same time.
+ *
+ *
+ * bool use_table_schema = 6 [(.google.api.field_behavior) = OPTIONAL];
+ *
+ * @return This builder for chaining.
+ */
+ public Builder clearUseTableSchema() {
+ bitField0_ = (bitField0_ & ~0x00000020);
+ useTableSchema_ = false;
+ onChanged();
+ return this;
+ }
+
@java.lang.Override
public final Builder setUnknownFields(final com.google.protobuf.UnknownFieldSet unknownFields) {
return super.setUnknownFields(unknownFields);
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/BigQueryConfigOrBuilder.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/BigQueryConfigOrBuilder.java
index a498ded18..bc805214f 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/BigQueryConfigOrBuilder.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/BigQueryConfigOrBuilder.java
@@ -54,11 +54,12 @@ public interface BigQueryConfigOrBuilder
*
*
*
- * When true, use the topic's schema as the columns to write to in BigQuery,
- * if it exists.
+ * Optional. When true, use the topic's schema as the columns to write to in
+ * BigQuery, if it exists. `use_topic_schema` and `use_table_schema` cannot be
+ * enabled at the same time.
*
*
- * bool use_topic_schema = 2;
+ * bool use_topic_schema = 2 [(.google.api.field_behavior) = OPTIONAL];
*
* @return The useTopicSchema.
*/
@@ -128,4 +129,19 @@ public interface BigQueryConfigOrBuilder
* @return The state.
*/
com.google.pubsub.v1.BigQueryConfig.State getState();
+
+ /**
+ *
+ *
+ *
+ * Optional. When true, use the BigQuery table's schema as the columns to
+ * write to in BigQuery. `use_table_schema` and `use_topic_schema` cannot be
+ * enabled at the same time.
+ *
+ *
+ * bool use_table_schema = 6 [(.google.api.field_behavior) = OPTIONAL];
+ *
+ * @return The useTableSchema.
+ */
+ boolean getUseTableSchema();
}
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CloudStorageConfig.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CloudStorageConfig.java
index 8fb85ab64..a4532a62f 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CloudStorageConfig.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CloudStorageConfig.java
@@ -682,7 +682,11 @@ public interface AvroConfigOrBuilder
*
*
* When true, write the subscription name, message_id, publish_time,
- * attributes, and ordering_key as additional fields in the output.
+ * attributes, and ordering_key as additional fields in the output. The
+ * subscription name, message_id, and publish_time fields are put in their
+ * own fields while all other message properties other than data (for
+ * example, an ordering_key, if present) are added as entries in the
+ * attributes map.
*
*
* bool write_metadata = 1;
@@ -741,7 +745,11 @@ public static final com.google.protobuf.Descriptors.Descriptor getDescriptor() {
*
*
* When true, write the subscription name, message_id, publish_time,
- * attributes, and ordering_key as additional fields in the output.
+ * attributes, and ordering_key as additional fields in the output. The
+ * subscription name, message_id, and publish_time fields are put in their
+ * own fields while all other message properties other than data (for
+ * example, an ordering_key, if present) are added as entries in the
+ * attributes map.
*
*
* bool write_metadata = 1;
@@ -1104,7 +1112,11 @@ public Builder mergeFrom(
*
*
* When true, write the subscription name, message_id, publish_time,
- * attributes, and ordering_key as additional fields in the output.
+ * attributes, and ordering_key as additional fields in the output. The
+ * subscription name, message_id, and publish_time fields are put in their
+ * own fields while all other message properties other than data (for
+ * example, an ordering_key, if present) are added as entries in the
+ * attributes map.
*
*
* bool write_metadata = 1;
@@ -1120,7 +1132,11 @@ public boolean getWriteMetadata() {
*
*
* When true, write the subscription name, message_id, publish_time,
- * attributes, and ordering_key as additional fields in the output.
+ * attributes, and ordering_key as additional fields in the output. The
+ * subscription name, message_id, and publish_time fields are put in their
+ * own fields while all other message properties other than data (for
+ * example, an ordering_key, if present) are added as entries in the
+ * attributes map.
*
*
* bool write_metadata = 1;
@@ -1140,7 +1156,11 @@ public Builder setWriteMetadata(boolean value) {
*
*
* When true, write the subscription name, message_id, publish_time,
- * attributes, and ordering_key as additional fields in the output.
+ * attributes, and ordering_key as additional fields in the output. The
+ * subscription name, message_id, and publish_time fields are put in their
+ * own fields while all other message properties other than data (for
+ * example, an ordering_key, if present) are added as entries in the
+ * attributes map.
*
*
* bool write_metadata = 1;
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CreateSnapshotRequest.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CreateSnapshotRequest.java
index 58c4a1896..3918f5ca6 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CreateSnapshotRequest.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CreateSnapshotRequest.java
@@ -86,8 +86,8 @@ protected com.google.protobuf.MapField internalGetMapField(int number) {
* in the request, the server will assign a random name for this snapshot on
* the same project as the subscription. Note that for REST API requests, you
* must specify a name. See the [resource name
- * rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format
- * is `projects/{project}/snapshots/{snap}`.
+ * rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * Format is `projects/{project}/snapshots/{snap}`.
*
*
*
@@ -116,8 +116,8 @@ public java.lang.String getName() {
* in the request, the server will assign a random name for this snapshot on
* the same project as the subscription. Note that for REST API requests, you
* must specify a name. See the [resource name
- * rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format
- * is `projects/{project}/snapshots/{snap}`.
+ * rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * Format is `projects/{project}/snapshots/{snap}`.
*
*
*
@@ -746,8 +746,8 @@ public Builder mergeFrom(
* in the request, the server will assign a random name for this snapshot on
* the same project as the subscription. Note that for REST API requests, you
* must specify a name. See the [resource name
- * rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format
- * is `projects/{project}/snapshots/{snap}`.
+ * rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * Format is `projects/{project}/snapshots/{snap}`.
*
*
*
@@ -775,8 +775,8 @@ public java.lang.String getName() {
* in the request, the server will assign a random name for this snapshot on
* the same project as the subscription. Note that for REST API requests, you
* must specify a name. See the [resource name
- * rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format
- * is `projects/{project}/snapshots/{snap}`.
+ * rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * Format is `projects/{project}/snapshots/{snap}`.
*
*
*
@@ -804,8 +804,8 @@ public com.google.protobuf.ByteString getNameBytes() {
* in the request, the server will assign a random name for this snapshot on
* the same project as the subscription. Note that for REST API requests, you
* must specify a name. See the [resource name
- * rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format
- * is `projects/{project}/snapshots/{snap}`.
+ * rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * Format is `projects/{project}/snapshots/{snap}`.
*
*
*
@@ -832,8 +832,8 @@ public Builder setName(java.lang.String value) {
* in the request, the server will assign a random name for this snapshot on
* the same project as the subscription. Note that for REST API requests, you
* must specify a name. See the [resource name
- * rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format
- * is `projects/{project}/snapshots/{snap}`.
+ * rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * Format is `projects/{project}/snapshots/{snap}`.
*
*
*
*
* @deprecated google.pubsub.v1.PullRequest.return_immediately is deprecated. See
- * google/pubsub/v1/pubsub.proto;l=1222
+ * google/pubsub/v1/pubsub.proto;l=1233
* @return The returnImmediately.
*/
@java.lang.Deprecated
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SchemaName.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SchemaName.java
index 1b2c9a908..2d8968ddf 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SchemaName.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SchemaName.java
@@ -137,7 +137,7 @@ public boolean equals(Object o) {
if (o == this) {
return true;
}
- if (o != null || getClass() == o.getClass()) {
+ if (o != null && getClass() == o.getClass()) {
SchemaName that = ((SchemaName) o);
return Objects.equals(this.project, that.project) && Objects.equals(this.schema, that.schema);
}
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SnapshotName.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SnapshotName.java
index 2aba349b3..4642f2323 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SnapshotName.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SnapshotName.java
@@ -137,7 +137,7 @@ public boolean equals(Object o) {
if (o == this) {
return true;
}
- if (o != null || getClass() == o.getClass()) {
+ if (o != null && getClass() == o.getClass()) {
SnapshotName that = ((SnapshotName) o);
return Objects.equals(this.project, that.project)
&& Objects.equals(this.snapshot, that.snapshot);
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SubscriptionName.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SubscriptionName.java
index 8ed44f614..ad49b90dd 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SubscriptionName.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/SubscriptionName.java
@@ -137,7 +137,7 @@ public boolean equals(Object o) {
if (o == this) {
return true;
}
- if (o != null || getClass() == o.getClass()) {
+ if (o != null && getClass() == o.getClass()) {
SubscriptionName that = ((SubscriptionName) o);
return Objects.equals(this.project, that.project)
&& Objects.equals(this.subscription, that.subscription);
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/TopicName.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/TopicName.java
index 8af73d814..6fc356a2b 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/TopicName.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/TopicName.java
@@ -178,7 +178,7 @@ public boolean equals(Object o) {
if (o == this) {
return true;
}
- if (o != null || getClass() == o.getClass()) {
+ if (o != null && getClass() == o.getClass()) {
TopicName that = ((TopicName) o);
return Objects.equals(this.project, that.project) && Objects.equals(this.topic, that.topic);
}
diff --git a/renovate.json b/renovate.json
index 6686189a1..977082821 100644
--- a/renovate.json
+++ b/renovate.json
@@ -10,7 +10,10 @@
":maintainLockFilesDisabled",
":autodetectPinVersions"
],
- "ignorePaths": [".kokoro/requirements.txt"],
+ "ignorePaths": [
+ ".kokoro/requirements.txt",
+ ".github/workflows/**"
+ ],
"packageRules": [
{
"packagePatterns": [
diff --git a/samples/install-without-bom/pom.xml b/samples/install-without-bom/pom.xml
index d99e15929..5c1280ed1 100644
--- a/samples/install-without-bom/pom.xml
+++ b/samples/install-without-bom/pom.xml
@@ -44,20 +44,20 @@
@@ -856,8 +856,8 @@ public Builder clearName() {
* in the request, the server will assign a random name for this snapshot on
* the same project as the subscription. Note that for REST API requests, you
* must specify a name. See the [resource name
- * rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format
- * is `projects/{project}/snapshots/{snap}`.
+ * rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * Format is `projects/{project}/snapshots/{snap}`.
*
*
*
*
* @deprecated google.pubsub.v1.PullRequest.return_immediately is deprecated. See
- * google/pubsub/v1/pubsub.proto;l=1222
+ * google/pubsub/v1/pubsub.proto;l=1233
* @return This builder for chaining.
*/
@java.lang.Deprecated
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PullRequestOrBuilder.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PullRequestOrBuilder.java
index 5cb9c98a3..9f9ccf387 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PullRequestOrBuilder.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PullRequestOrBuilder.java
@@ -71,7 +71,7 @@ public interface PullRequestOrBuilder
*
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CreateSnapshotRequestOrBuilder.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CreateSnapshotRequestOrBuilder.java
index 2f24bc123..ee4a6d68f 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CreateSnapshotRequestOrBuilder.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/CreateSnapshotRequestOrBuilder.java
@@ -31,8 +31,8 @@ public interface CreateSnapshotRequestOrBuilder
* in the request, the server will assign a random name for this snapshot on
* the same project as the subscription. Note that for REST API requests, you
* must specify a name. See the [resource name
- * rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format
- * is `projects/{project}/snapshots/{snap}`.
+ * rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * Format is `projects/{project}/snapshots/{snap}`.
*
*
*
*
* @deprecated google.pubsub.v1.PullRequest.return_immediately is deprecated. See
- * google/pubsub/v1/pubsub.proto;l=1222
+ * google/pubsub/v1/pubsub.proto;l=1233
* @param value The returnImmediately to set.
* @return This builder for chaining.
*/
@@ -743,7 +743,7 @@ public Builder setReturnImmediately(boolean value) {
*
@@ -50,8 +50,8 @@ public interface CreateSnapshotRequestOrBuilder
* in the request, the server will assign a random name for this snapshot on
* the same project as the subscription. Note that for REST API requests, you
* must specify a name. See the [resource name
- * rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format
- * is `projects/{project}/snapshots/{snap}`.
+ * rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ * Format is `projects/{project}/snapshots/{snap}`.
*
*
*
*
* @deprecated google.pubsub.v1.PullRequest.return_immediately is deprecated. See
- * google/pubsub/v1/pubsub.proto;l=1222
+ * google/pubsub/v1/pubsub.proto;l=1233
* @return The returnImmediately.
*/
@java.lang.Override
@@ -713,7 +713,7 @@ public boolean getReturnImmediately() {
*
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/MessageStoragePolicy.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/MessageStoragePolicy.java
index afec846d7..06c6e9aba 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/MessageStoragePolicy.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/MessageStoragePolicy.java
@@ -71,11 +71,12 @@ public static final com.google.protobuf.Descriptors.Descriptor getDescriptor() {
*
*
*
*
* @deprecated google.pubsub.v1.PullRequest.return_immediately is deprecated. See
- * google/pubsub/v1/pubsub.proto;l=1222
+ * google/pubsub/v1/pubsub.proto;l=1233
* @return The returnImmediately.
*/
@java.lang.Override
@@ -687,7 +687,7 @@ public Builder setSubscriptionBytes(com.google.protobuf.ByteString value) {
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -89,11 +90,12 @@ public com.google.protobuf.ProtocolStringList getAllowedPersistenceRegionsList()
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -107,11 +109,12 @@ public int getAllowedPersistenceRegionsCount() {
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -126,11 +129,12 @@ public java.lang.String getAllowedPersistenceRegions(int index) {
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -513,11 +517,12 @@ private void ensureAllowedPersistenceRegionsIsMutable() {
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -532,11 +537,12 @@ public com.google.protobuf.ProtocolStringList getAllowedPersistenceRegionsList()
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -550,11 +556,12 @@ public int getAllowedPersistenceRegionsCount() {
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -569,11 +576,12 @@ public java.lang.String getAllowedPersistenceRegions(int index) {
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -588,11 +596,12 @@ public com.google.protobuf.ByteString getAllowedPersistenceRegionsBytes(int inde
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -615,11 +624,12 @@ public Builder setAllowedPersistenceRegions(int index, java.lang.String value) {
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -641,11 +651,12 @@ public Builder addAllowedPersistenceRegions(java.lang.String value) {
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -664,11 +675,12 @@ public Builder addAllAllowedPersistenceRegions(java.lang.Iterablerepeated string allowed_persistence_regions = 1;
@@ -686,11 +698,12 @@ public Builder clearAllowedPersistenceRegions() {
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/MessageStoragePolicyOrBuilder.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/MessageStoragePolicyOrBuilder.java
index 8edf41faa..5f075aca0 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/MessageStoragePolicyOrBuilder.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/MessageStoragePolicyOrBuilder.java
@@ -27,11 +27,12 @@ public interface MessageStoragePolicyOrBuilder
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -43,11 +44,12 @@ public interface MessageStoragePolicyOrBuilder
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -59,11 +61,12 @@ public interface MessageStoragePolicyOrBuilder
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
@@ -76,11 +79,12 @@ public interface MessageStoragePolicyOrBuilder
*
*
*
- * A list of IDs of GCP regions where messages that are published to the topic
- * may be persisted in storage. Messages published by publishers running in
- * non-allowed GCP regions (or running outside of GCP altogether) will be
- * routed for storage in one of the allowed regions. An empty list means that
- * no regions are allowed, and is not a valid configuration.
+ * A list of IDs of Google Cloud regions where messages that are published
+ * to the topic may be persisted in storage. Messages published by publishers
+ * running in non-allowed Google Cloud regions (or running outside of Google
+ * Cloud altogether) are routed for storage in one of the allowed regions.
+ * An empty list means that no regions are allowed, and is not a valid
+ * configuration.
*
*
* repeated string allowed_persistence_regions = 1;
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/ProjectName.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/ProjectName.java
index 2db62c0e7..d04475ab0 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/ProjectName.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/ProjectName.java
@@ -127,7 +127,7 @@ public boolean equals(Object o) {
if (o == this) {
return true;
}
- if (o != null || getClass() == o.getClass()) {
+ if (o != null && getClass() == o.getClass()) {
ProjectName that = ((ProjectName) o);
return Objects.equals(this.project, that.project);
}
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PubsubProto.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PubsubProto.java
index fcb75b41f..b680117a0 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PubsubProto.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PubsubProto.java
@@ -383,230 +383,231 @@ public static com.google.protobuf.Descriptors.FileDescriptor getDescriptor() {
+ "dience\030\002 \001(\t\032\017\n\rPubsubWrapper\032#\n\tNoWrapp"
+ "er\022\026\n\016write_metadata\030\001 \001(\010\0321\n\017Attributes"
+ "Entry\022\013\n\003key\030\001 \001(\t\022\r\n\005value\030\002 \001(\t:\0028\001B\027\n"
- + "\025authentication_methodB\t\n\007wrapper\"\222\002\n\016Bi"
- + "gQueryConfig\022\r\n\005table\030\001 \001(\t\022\030\n\020use_topic"
- + "_schema\030\002 \001(\010\022\026\n\016write_metadata\030\003 \001(\010\022\033\n"
- + "\023drop_unknown_fields\030\004 \001(\010\022;\n\005state\030\005 \001("
- + "\0162&.google.pubsub.v1.BigQueryConfig.Stat"
- + "eB\004\342A\001\003\"e\n\005State\022\025\n\021STATE_UNSPECIFIED\020\000\022"
- + "\n\n\006ACTIVE\020\001\022\025\n\021PERMISSION_DENIED\020\002\022\r\n\tNO"
- + "T_FOUND\020\003\022\023\n\017SCHEMA_MISMATCH\020\004\"\210\004\n\022Cloud"
- + "StorageConfig\022\024\n\006bucket\030\001 \001(\tB\004\342A\001\002\022\027\n\017f"
- + "ilename_prefix\030\002 \001(\t\022\027\n\017filename_suffix\030"
- + "\003 \001(\t\022F\n\013text_config\030\004 \001(\0132/.google.pubs"
- + "ub.v1.CloudStorageConfig.TextConfigH\000\022F\n"
- + "\013avro_config\030\005 \001(\0132/.google.pubsub.v1.Cl"
- + "oudStorageConfig.AvroConfigH\000\022/\n\014max_dur"
- + "ation\030\006 \001(\0132\031.google.protobuf.Duration\022\021"
- + "\n\tmax_bytes\030\007 \001(\003\022?\n\005state\030\t \001(\0162*.googl"
- + "e.pubsub.v1.CloudStorageConfig.StateB\004\342A"
- + "\001\003\032\014\n\nTextConfig\032$\n\nAvroConfig\022\026\n\016write_"
- + "metadata\030\001 \001(\010\"P\n\005State\022\025\n\021STATE_UNSPECI"
- + "FIED\020\000\022\n\n\006ACTIVE\020\001\022\025\n\021PERMISSION_DENIED\020"
- + "\002\022\r\n\tNOT_FOUND\020\003B\017\n\routput_format\"m\n\017Rec"
- + "eivedMessage\022\016\n\006ack_id\030\001 \001(\t\0220\n\007message\030"
- + "\002 \001(\0132\037.google.pubsub.v1.PubsubMessage\022\030"
- + "\n\020delivery_attempt\030\003 \001(\005\"[\n\026GetSubscript"
- + "ionRequest\022A\n\014subscription\030\001 \001(\tB+\342A\001\002\372A"
- + "$\n\"pubsub.googleapis.com/Subscription\"\216\001"
- + "\n\031UpdateSubscriptionRequest\022:\n\014subscript"
- + "ion\030\001 \001(\0132\036.google.pubsub.v1.Subscriptio"
- + "nB\004\342A\001\002\0225\n\013update_mask\030\002 \001(\0132\032.google.pr"
- + "otobuf.FieldMaskB\004\342A\001\002\"\210\001\n\030ListSubscript"
- + "ionsRequest\022E\n\007project\030\001 \001(\tB4\342A\001\002\372A-\n+c"
- + "loudresourcemanager.googleapis.com/Proje"
- + "ct\022\021\n\tpage_size\030\002 \001(\005\022\022\n\npage_token\030\003 \001("
- + "\t\"k\n\031ListSubscriptionsResponse\0225\n\rsubscr"
- + "iptions\030\001 \003(\0132\036.google.pubsub.v1.Subscri"
- + "ption\022\027\n\017next_page_token\030\002 \001(\t\"^\n\031Delete"
- + "SubscriptionRequest\022A\n\014subscription\030\001 \001("
- + "\tB+\342A\001\002\372A$\n\"pubsub.googleapis.com/Subscr"
- + "iption\"\225\001\n\027ModifyPushConfigRequest\022A\n\014su"
- + "bscription\030\001 \001(\tB+\342A\001\002\372A$\n\"pubsub.google"
- + "apis.com/Subscription\0227\n\013push_config\030\002 \001"
- + "(\0132\034.google.pubsub.v1.PushConfigB\004\342A\001\002\"\220"
- + "\001\n\013PullRequest\022A\n\014subscription\030\001 \001(\tB+\342A"
- + "\001\002\372A$\n\"pubsub.googleapis.com/Subscriptio"
- + "n\022\"\n\022return_immediately\030\002 \001(\010B\006\030\001\342A\001\001\022\032\n"
- + "\014max_messages\030\003 \001(\005B\004\342A\001\002\"L\n\014PullRespons"
- + "e\022<\n\021received_messages\030\001 \003(\0132!.google.pu"
- + "bsub.v1.ReceivedMessage\"\230\001\n\030ModifyAckDea"
- + "dlineRequest\022A\n\014subscription\030\001 \001(\tB+\342A\001\002"
+ + "\025authentication_methodB\t\n\007wrapper\"\270\002\n\016Bi"
+ + "gQueryConfig\022\r\n\005table\030\001 \001(\t\022\036\n\020use_topic"
+ + "_schema\030\002 \001(\010B\004\342A\001\001\022\026\n\016write_metadata\030\003 "
+ + "\001(\010\022\033\n\023drop_unknown_fields\030\004 \001(\010\022;\n\005stat"
+ + "e\030\005 \001(\0162&.google.pubsub.v1.BigQueryConfi"
+ + "g.StateB\004\342A\001\003\022\036\n\020use_table_schema\030\006 \001(\010B"
+ + "\004\342A\001\001\"e\n\005State\022\025\n\021STATE_UNSPECIFIED\020\000\022\n\n"
+ + "\006ACTIVE\020\001\022\025\n\021PERMISSION_DENIED\020\002\022\r\n\tNOT_"
+ + "FOUND\020\003\022\023\n\017SCHEMA_MISMATCH\020\004\"\210\004\n\022CloudSt"
+ + "orageConfig\022\024\n\006bucket\030\001 \001(\tB\004\342A\001\002\022\027\n\017fil"
+ + "ename_prefix\030\002 \001(\t\022\027\n\017filename_suffix\030\003 "
+ + "\001(\t\022F\n\013text_config\030\004 \001(\0132/.google.pubsub"
+ + ".v1.CloudStorageConfig.TextConfigH\000\022F\n\013a"
+ + "vro_config\030\005 \001(\0132/.google.pubsub.v1.Clou"
+ + "dStorageConfig.AvroConfigH\000\022/\n\014max_durat"
+ + "ion\030\006 \001(\0132\031.google.protobuf.Duration\022\021\n\t"
+ + "max_bytes\030\007 \001(\003\022?\n\005state\030\t \001(\0162*.google."
+ + "pubsub.v1.CloudStorageConfig.StateB\004\342A\001\003"
+ + "\032\014\n\nTextConfig\032$\n\nAvroConfig\022\026\n\016write_me"
+ + "tadata\030\001 \001(\010\"P\n\005State\022\025\n\021STATE_UNSPECIFI"
+ + "ED\020\000\022\n\n\006ACTIVE\020\001\022\025\n\021PERMISSION_DENIED\020\002\022"
+ + "\r\n\tNOT_FOUND\020\003B\017\n\routput_format\"m\n\017Recei"
+ + "vedMessage\022\016\n\006ack_id\030\001 \001(\t\0220\n\007message\030\002 "
+ + "\001(\0132\037.google.pubsub.v1.PubsubMessage\022\030\n\020"
+ + "delivery_attempt\030\003 \001(\005\"[\n\026GetSubscriptio"
+ + "nRequest\022A\n\014subscription\030\001 \001(\tB+\342A\001\002\372A$\n"
+ + "\"pubsub.googleapis.com/Subscription\"\216\001\n\031"
+ + "UpdateSubscriptionRequest\022:\n\014subscriptio"
+ + "n\030\001 \001(\0132\036.google.pubsub.v1.SubscriptionB"
+ + "\004\342A\001\002\0225\n\013update_mask\030\002 \001(\0132\032.google.prot"
+ + "obuf.FieldMaskB\004\342A\001\002\"\210\001\n\030ListSubscriptio"
+ + "nsRequest\022E\n\007project\030\001 \001(\tB4\342A\001\002\372A-\n+clo"
+ + "udresourcemanager.googleapis.com/Project"
+ + "\022\021\n\tpage_size\030\002 \001(\005\022\022\n\npage_token\030\003 \001(\t\""
+ + "k\n\031ListSubscriptionsResponse\0225\n\rsubscrip"
+ + "tions\030\001 \003(\0132\036.google.pubsub.v1.Subscript"
+ + "ion\022\027\n\017next_page_token\030\002 \001(\t\"^\n\031DeleteSu"
+ + "bscriptionRequest\022A\n\014subscription\030\001 \001(\tB"
+ + "+\342A\001\002\372A$\n\"pubsub.googleapis.com/Subscrip"
+ + "tion\"\225\001\n\027ModifyPushConfigRequest\022A\n\014subs"
+ + "cription\030\001 \001(\tB+\342A\001\002\372A$\n\"pubsub.googleap"
+ + "is.com/Subscription\0227\n\013push_config\030\002 \001(\013"
+ + "2\034.google.pubsub.v1.PushConfigB\004\342A\001\002\"\220\001\n"
+ + "\013PullRequest\022A\n\014subscription\030\001 \001(\tB+\342A\001\002"
+ "\372A$\n\"pubsub.googleapis.com/Subscription\022"
- + "\025\n\007ack_ids\030\004 \003(\tB\004\342A\001\002\022\"\n\024ack_deadline_s"
- + "econds\030\003 \001(\005B\004\342A\001\002\"n\n\022AcknowledgeRequest"
- + "\022A\n\014subscription\030\001 \001(\tB+\342A\001\002\372A$\n\"pubsub."
- + "googleapis.com/Subscription\022\025\n\007ack_ids\030\002"
- + " \003(\tB\004\342A\001\002\"\253\002\n\024StreamingPullRequest\022A\n\014s"
- + "ubscription\030\001 \001(\tB+\342A\001\002\372A$\n\"pubsub.googl"
- + "eapis.com/Subscription\022\017\n\007ack_ids\030\002 \003(\t\022"
- + "\037\n\027modify_deadline_seconds\030\003 \003(\005\022\037\n\027modi"
- + "fy_deadline_ack_ids\030\004 \003(\t\022)\n\033stream_ack_"
- + "deadline_seconds\030\005 \001(\005B\004\342A\001\002\022\021\n\tclient_i"
- + "d\030\006 \001(\t\022 \n\030max_outstanding_messages\030\007 \001("
- + "\003\022\035\n\025max_outstanding_bytes\030\010 \001(\003\"\335\005\n\025Str"
- + "eamingPullResponse\022<\n\021received_messages\030"
- + "\001 \003(\0132!.google.pubsub.v1.ReceivedMessage"
- + "\022a\n\030acknowledge_confirmation\030\005 \001(\0132?.goo"
- + "gle.pubsub.v1.StreamingPullResponse.Ackn"
- + "owledgeConfirmation\022o\n modify_ack_deadli"
- + "ne_confirmation\030\003 \001(\0132E.google.pubsub.v1"
- + ".StreamingPullResponse.ModifyAckDeadline"
- + "Confirmation\022_\n\027subscription_properties\030"
- + "\004 \001(\0132>.google.pubsub.v1.StreamingPullRe"
- + "sponse.SubscriptionProperties\032\200\001\n\027Acknow"
- + "ledgeConfirmation\022\017\n\007ack_ids\030\001 \003(\t\022\027\n\017in"
- + "valid_ack_ids\030\002 \003(\t\022\031\n\021unordered_ack_ids"
- + "\030\003 \003(\t\022 \n\030temporary_failed_ack_ids\030\004 \003(\t"
- + "\032k\n\035ModifyAckDeadlineConfirmation\022\017\n\007ack"
- + "_ids\030\001 \003(\t\022\027\n\017invalid_ack_ids\030\002 \003(\t\022 \n\030t"
- + "emporary_failed_ack_ids\030\003 \003(\t\032a\n\026Subscri"
- + "ptionProperties\022%\n\035exactly_once_delivery"
- + "_enabled\030\001 \001(\010\022 \n\030message_ordering_enabl"
- + "ed\030\002 \001(\010\"\205\002\n\025CreateSnapshotRequest\0225\n\004na"
- + "me\030\001 \001(\tB\'\342A\001\002\372A \n\036pubsub.googleapis.com"
- + "/Snapshot\022A\n\014subscription\030\002 \001(\tB+\342A\001\002\372A$"
- + "\n\"pubsub.googleapis.com/Subscription\022C\n\006"
- + "labels\030\003 \003(\01323.google.pubsub.v1.CreateSn"
- + "apshotRequest.LabelsEntry\032-\n\013LabelsEntry"
- + "\022\013\n\003key\030\001 \001(\t\022\r\n\005value\030\002 \001(\t:\0028\001\"\202\001\n\025Upd"
- + "ateSnapshotRequest\0222\n\010snapshot\030\001 \001(\0132\032.g"
- + "oogle.pubsub.v1.SnapshotB\004\342A\001\002\0225\n\013update"
- + "_mask\030\002 \001(\0132\032.google.protobuf.FieldMaskB"
- + "\004\342A\001\002\"\257\002\n\010Snapshot\022\014\n\004name\030\001 \001(\t\022/\n\005topi"
- + "c\030\002 \001(\tB \372A\035\n\033pubsub.googleapis.com/Topi"
- + "c\022/\n\013expire_time\030\003 \001(\0132\032.google.protobuf"
- + ".Timestamp\0226\n\006labels\030\004 \003(\0132&.google.pubs"
- + "ub.v1.Snapshot.LabelsEntry\032-\n\013LabelsEntr"
- + "y\022\013\n\003key\030\001 \001(\t\022\r\n\005value\030\002 \001(\t:\0028\001:L\352AI\n\036"
- + "pubsub.googleapis.com/Snapshot\022\'projects"
- + "/{project}/snapshots/{snapshot}\"O\n\022GetSn"
- + "apshotRequest\0229\n\010snapshot\030\001 \001(\tB\'\342A\001\002\372A "
- + "\n\036pubsub.googleapis.com/Snapshot\"\204\001\n\024Lis"
- + "tSnapshotsRequest\022E\n\007project\030\001 \001(\tB4\342A\001\002"
- + "\372A-\n+cloudresourcemanager.googleapis.com"
- + "/Project\022\021\n\tpage_size\030\002 \001(\005\022\022\n\npage_toke"
- + "n\030\003 \001(\t\"_\n\025ListSnapshotsResponse\022-\n\tsnap"
- + "shots\030\001 \003(\0132\032.google.pubsub.v1.Snapshot\022"
- + "\027\n\017next_page_token\030\002 \001(\t\"R\n\025DeleteSnapsh"
- + "otRequest\0229\n\010snapshot\030\001 \001(\tB\'\342A\001\002\372A \n\036pu"
- + "bsub.googleapis.com/Snapshot\"\277\001\n\013SeekReq"
- + "uest\022A\n\014subscription\030\001 \001(\tB+\342A\001\002\372A$\n\"pub"
- + "sub.googleapis.com/Subscription\022*\n\004time\030"
- + "\002 \001(\0132\032.google.protobuf.TimestampH\000\0227\n\010s"
- + "napshot\030\003 \001(\tB#\372A \n\036pubsub.googleapis.co"
- + "m/SnapshotH\000B\010\n\006target\"\016\n\014SeekResponse2\270"
- + "\013\n\tPublisher\022q\n\013CreateTopic\022\027.google.pub"
- + "sub.v1.Topic\032\027.google.pubsub.v1.Topic\"0\332"
- + "A\004name\202\323\344\223\002#\032\036/v1/{name=projects/*/topic"
- + "s/*}:\001*\022\221\001\n\013UpdateTopic\022$.google.pubsub."
- + "v1.UpdateTopicRequest\032\027.google.pubsub.v1"
- + ".Topic\"C\332A\021topic,update_mask\202\323\344\223\002)2$/v1/"
- + "{topic.name=projects/*/topics/*}:\001*\022\223\001\n\007"
- + "Publish\022 .google.pubsub.v1.PublishReques"
- + "t\032!.google.pubsub.v1.PublishResponse\"C\332A"
- + "\016topic,messages\202\323\344\223\002,\"\'/v1/{topic=projec"
- + "ts/*/topics/*}:publish:\001*\022w\n\010GetTopic\022!."
- + "google.pubsub.v1.GetTopicRequest\032\027.googl"
- + "e.pubsub.v1.Topic\"/\332A\005topic\202\323\344\223\002!\022\037/v1/{"
- + "topic=projects/*/topics/*}\022\212\001\n\nListTopic"
- + "s\022#.google.pubsub.v1.ListTopicsRequest\032$"
- + ".google.pubsub.v1.ListTopicsResponse\"1\332A"
- + "\007project\202\323\344\223\002!\022\037/v1/{project=projects/*}"
- + "/topics\022\272\001\n\026ListTopicSubscriptions\022/.goo"
- + "gle.pubsub.v1.ListTopicSubscriptionsRequ"
- + "est\0320.google.pubsub.v1.ListTopicSubscrip"
- + "tionsResponse\"=\332A\005topic\202\323\344\223\002/\022-/v1/{topi"
- + "c=projects/*/topics/*}/subscriptions\022\252\001\n"
- + "\022ListTopicSnapshots\022+.google.pubsub.v1.L"
- + "istTopicSnapshotsRequest\032,.google.pubsub"
- + ".v1.ListTopicSnapshotsResponse\"9\332A\005topic"
- + "\202\323\344\223\002+\022)/v1/{topic=projects/*/topics/*}/"
- + "snapshots\022|\n\013DeleteTopic\022$.google.pubsub"
- + ".v1.DeleteTopicRequest\032\026.google.protobuf"
- + ".Empty\"/\332A\005topic\202\323\344\223\002!*\037/v1/{topic=proje"
- + "cts/*/topics/*}\022\255\001\n\022DetachSubscription\022+"
- + ".google.pubsub.v1.DetachSubscriptionRequ"
- + "est\032,.google.pubsub.v1.DetachSubscriptio"
- + "nResponse\"<\202\323\344\223\0026\"4/v1/{subscription=pro"
- + "jects/*/subscriptions/*}:detach\032p\312A\025pubs"
- + "ub.googleapis.com\322AUhttps://www.googleap"
- + "is.com/auth/cloud-platform,https://www.g"
- + "oogleapis.com/auth/pubsub2\322\025\n\nSubscriber"
- + "\022\264\001\n\022CreateSubscription\022\036.google.pubsub."
- + "v1.Subscription\032\036.google.pubsub.v1.Subsc"
- + "ription\"^\332A+name,topic,push_config,ack_d"
- + "eadline_seconds\202\323\344\223\002*\032%/v1/{name=project"
- + "s/*/subscriptions/*}:\001*\022\241\001\n\017GetSubscript"
- + "ion\022(.google.pubsub.v1.GetSubscriptionRe"
- + "quest\032\036.google.pubsub.v1.Subscription\"D\332"
- + "A\014subscription\202\323\344\223\002/\022-/v1/{subscription="
- + "projects/*/subscriptions/*}\022\273\001\n\022UpdateSu"
- + "bscription\022+.google.pubsub.v1.UpdateSubs"
- + "criptionRequest\032\036.google.pubsub.v1.Subsc"
- + "ription\"X\332A\030subscription,update_mask\202\323\344\223"
- + "\002722/v1/{subscription.name=projects/*/su"
- + "bscriptions/*}:\001*\022\246\001\n\021ListSubscriptions\022"
- + "*.google.pubsub.v1.ListSubscriptionsRequ"
- + "est\032+.google.pubsub.v1.ListSubscriptions"
- + "Response\"8\332A\007project\202\323\344\223\002(\022&/v1/{project"
- + "=projects/*}/subscriptions\022\237\001\n\022DeleteSub"
- + "scription\022+.google.pubsub.v1.DeleteSubsc"
- + "riptionRequest\032\026.google.protobuf.Empty\"D"
- + "\332A\014subscription\202\323\344\223\002/*-/v1/{subscription"
- + "=projects/*/subscriptions/*}\022\317\001\n\021ModifyA"
- + "ckDeadline\022*.google.pubsub.v1.ModifyAckD"
- + "eadlineRequest\032\026.google.protobuf.Empty\"v"
- + "\332A)subscription,ack_ids,ack_deadline_sec"
- + "onds\202\323\344\223\002D\"?/v1/{subscription=projects/*"
- + "/subscriptions/*}:modifyAckDeadline:\001*\022\250"
- + "\001\n\013Acknowledge\022$.google.pubsub.v1.Acknow"
- + "ledgeRequest\032\026.google.protobuf.Empty\"[\332A"
- + "\024subscription,ack_ids\202\323\344\223\002>\"9/v1/{subscr"
- + "iption=projects/*/subscriptions/*}:ackno"
- + "wledge:\001*\022\320\001\n\004Pull\022\035.google.pubsub.v1.Pu"
- + "llRequest\032\036.google.pubsub.v1.PullRespons"
- + "e\"\210\001\332A,subscription,return_immediately,m"
- + "ax_messages\332A\031subscription,max_messages\202"
- + "\323\344\223\0027\"2/v1/{subscription=projects/*/subs"
- + "criptions/*}:pull:\001*\022f\n\rStreamingPull\022&."
- + "google.pubsub.v1.StreamingPullRequest\032\'."
- + "google.pubsub.v1.StreamingPullResponse\"\000"
- + "(\0010\001\022\273\001\n\020ModifyPushConfig\022).google.pubsu"
- + "b.v1.ModifyPushConfigRequest\032\026.google.pr"
- + "otobuf.Empty\"d\332A\030subscription,push_confi"
- + "g\202\323\344\223\002C\">/v1/{subscription=projects/*/su"
- + "bscriptions/*}:modifyPushConfig:\001*\022\211\001\n\013G"
- + "etSnapshot\022$.google.pubsub.v1.GetSnapsho"
- + "tRequest\032\032.google.pubsub.v1.Snapshot\"8\332A"
- + "\010snapshot\202\323\344\223\002\'\022%/v1/{snapshot=projects/"
- + "*/snapshots/*}\022\226\001\n\rListSnapshots\022&.googl"
- + "e.pubsub.v1.ListSnapshotsRequest\032\'.googl"
- + "e.pubsub.v1.ListSnapshotsResponse\"4\332A\007pr"
- + "oject\202\323\344\223\002$\022\"/v1/{project=projects/*}/sn"
- + "apshots\022\227\001\n\016CreateSnapshot\022\'.google.pubs"
- + "ub.v1.CreateSnapshotRequest\032\032.google.pub"
- + "sub.v1.Snapshot\"@\332A\021name,subscription\202\323\344"
- + "\223\002&\032!/v1/{name=projects/*/snapshots/*}:\001"
- + "*\022\243\001\n\016UpdateSnapshot\022\'.google.pubsub.v1."
- + "UpdateSnapshotRequest\032\032.google.pubsub.v1"
- + ".Snapshot\"L\332A\024snapshot,update_mask\202\323\344\223\002/"
- + "2*/v1/{snapshot.name=projects/*/snapshot"
- + "s/*}:\001*\022\213\001\n\016DeleteSnapshot\022\'.google.pubs"
- + "ub.v1.DeleteSnapshotRequest\032\026.google.pro"
- + "tobuf.Empty\"8\332A\010snapshot\202\323\344\223\002\'*%/v1/{sna"
- + "pshot=projects/*/snapshots/*}\022\204\001\n\004Seek\022\035"
- + ".google.pubsub.v1.SeekRequest\032\036.google.p"
- + "ubsub.v1.SeekResponse\"=\202\323\344\223\0027\"2/v1/{subs"
- + "cription=projects/*/subscriptions/*}:see"
- + "k:\001*\032p\312A\025pubsub.googleapis.com\322AUhttps:/"
- + "/www.googleapis.com/auth/cloud-platform,"
- + "https://www.googleapis.com/auth/pubsubB\252"
- + "\001\n\024com.google.pubsub.v1B\013PubsubProtoP\001Z2"
- + "cloud.google.com/go/pubsub/apiv1/pubsubp"
- + "b;pubsubpb\370\001\001\252\002\026Google.Cloud.PubSub.V1\312\002"
- + "\026Google\\Cloud\\PubSub\\V1\352\002\031Google::Cloud:"
- + ":PubSub::V1b\006proto3"
+ + "\"\n\022return_immediately\030\002 \001(\010B\006\030\001\342A\001\001\022\032\n\014m"
+ + "ax_messages\030\003 \001(\005B\004\342A\001\002\"L\n\014PullResponse\022"
+ + "<\n\021received_messages\030\001 \003(\0132!.google.pubs"
+ + "ub.v1.ReceivedMessage\"\230\001\n\030ModifyAckDeadl"
+ + "ineRequest\022A\n\014subscription\030\001 \001(\tB+\342A\001\002\372A"
+ + "$\n\"pubsub.googleapis.com/Subscription\022\025\n"
+ + "\007ack_ids\030\004 \003(\tB\004\342A\001\002\022\"\n\024ack_deadline_sec"
+ + "onds\030\003 \001(\005B\004\342A\001\002\"n\n\022AcknowledgeRequest\022A"
+ + "\n\014subscription\030\001 \001(\tB+\342A\001\002\372A$\n\"pubsub.go"
+ + "ogleapis.com/Subscription\022\025\n\007ack_ids\030\002 \003"
+ + "(\tB\004\342A\001\002\"\253\002\n\024StreamingPullRequest\022A\n\014sub"
+ + "scription\030\001 \001(\tB+\342A\001\002\372A$\n\"pubsub.googlea"
+ + "pis.com/Subscription\022\017\n\007ack_ids\030\002 \003(\t\022\037\n"
+ + "\027modify_deadline_seconds\030\003 \003(\005\022\037\n\027modify"
+ + "_deadline_ack_ids\030\004 \003(\t\022)\n\033stream_ack_de"
+ + "adline_seconds\030\005 \001(\005B\004\342A\001\002\022\021\n\tclient_id\030"
+ + "\006 \001(\t\022 \n\030max_outstanding_messages\030\007 \001(\003\022"
+ + "\035\n\025max_outstanding_bytes\030\010 \001(\003\"\335\005\n\025Strea"
+ + "mingPullResponse\022<\n\021received_messages\030\001 "
+ + "\003(\0132!.google.pubsub.v1.ReceivedMessage\022a"
+ + "\n\030acknowledge_confirmation\030\005 \001(\0132?.googl"
+ + "e.pubsub.v1.StreamingPullResponse.Acknow"
+ + "ledgeConfirmation\022o\n modify_ack_deadline"
+ + "_confirmation\030\003 \001(\0132E.google.pubsub.v1.S"
+ + "treamingPullResponse.ModifyAckDeadlineCo"
+ + "nfirmation\022_\n\027subscription_properties\030\004 "
+ + "\001(\0132>.google.pubsub.v1.StreamingPullResp"
+ + "onse.SubscriptionProperties\032\200\001\n\027Acknowle"
+ + "dgeConfirmation\022\017\n\007ack_ids\030\001 \003(\t\022\027\n\017inva"
+ + "lid_ack_ids\030\002 \003(\t\022\031\n\021unordered_ack_ids\030\003"
+ + " \003(\t\022 \n\030temporary_failed_ack_ids\030\004 \003(\t\032k"
+ + "\n\035ModifyAckDeadlineConfirmation\022\017\n\007ack_i"
+ + "ds\030\001 \003(\t\022\027\n\017invalid_ack_ids\030\002 \003(\t\022 \n\030tem"
+ + "porary_failed_ack_ids\030\003 \003(\t\032a\n\026Subscript"
+ + "ionProperties\022%\n\035exactly_once_delivery_e"
+ + "nabled\030\001 \001(\010\022 \n\030message_ordering_enabled"
+ + "\030\002 \001(\010\"\205\002\n\025CreateSnapshotRequest\0225\n\004name"
+ + "\030\001 \001(\tB\'\342A\001\002\372A \n\036pubsub.googleapis.com/S"
+ + "napshot\022A\n\014subscription\030\002 \001(\tB+\342A\001\002\372A$\n\""
+ + "pubsub.googleapis.com/Subscription\022C\n\006la"
+ + "bels\030\003 \003(\01323.google.pubsub.v1.CreateSnap"
+ + "shotRequest.LabelsEntry\032-\n\013LabelsEntry\022\013"
+ + "\n\003key\030\001 \001(\t\022\r\n\005value\030\002 \001(\t:\0028\001\"\202\001\n\025Updat"
+ + "eSnapshotRequest\0222\n\010snapshot\030\001 \001(\0132\032.goo"
+ + "gle.pubsub.v1.SnapshotB\004\342A\001\002\0225\n\013update_m"
+ + "ask\030\002 \001(\0132\032.google.protobuf.FieldMaskB\004\342"
+ + "A\001\002\"\257\002\n\010Snapshot\022\014\n\004name\030\001 \001(\t\022/\n\005topic\030"
+ + "\002 \001(\tB \372A\035\n\033pubsub.googleapis.com/Topic\022"
+ + "/\n\013expire_time\030\003 \001(\0132\032.google.protobuf.T"
+ + "imestamp\0226\n\006labels\030\004 \003(\0132&.google.pubsub"
+ + ".v1.Snapshot.LabelsEntry\032-\n\013LabelsEntry\022"
+ + "\013\n\003key\030\001 \001(\t\022\r\n\005value\030\002 \001(\t:\0028\001:L\352AI\n\036pu"
+ + "bsub.googleapis.com/Snapshot\022\'projects/{"
+ + "project}/snapshots/{snapshot}\"O\n\022GetSnap"
+ + "shotRequest\0229\n\010snapshot\030\001 \001(\tB\'\342A\001\002\372A \n\036"
+ + "pubsub.googleapis.com/Snapshot\"\204\001\n\024ListS"
+ + "napshotsRequest\022E\n\007project\030\001 \001(\tB4\342A\001\002\372A"
+ + "-\n+cloudresourcemanager.googleapis.com/P"
+ + "roject\022\021\n\tpage_size\030\002 \001(\005\022\022\n\npage_token\030"
+ + "\003 \001(\t\"_\n\025ListSnapshotsResponse\022-\n\tsnapsh"
+ + "ots\030\001 \003(\0132\032.google.pubsub.v1.Snapshot\022\027\n"
+ + "\017next_page_token\030\002 \001(\t\"R\n\025DeleteSnapshot"
+ + "Request\0229\n\010snapshot\030\001 \001(\tB\'\342A\001\002\372A \n\036pubs"
+ + "ub.googleapis.com/Snapshot\"\277\001\n\013SeekReque"
+ + "st\022A\n\014subscription\030\001 \001(\tB+\342A\001\002\372A$\n\"pubsu"
+ + "b.googleapis.com/Subscription\022*\n\004time\030\002 "
+ + "\001(\0132\032.google.protobuf.TimestampH\000\0227\n\010sna"
+ + "pshot\030\003 \001(\tB#\372A \n\036pubsub.googleapis.com/"
+ + "SnapshotH\000B\010\n\006target\"\016\n\014SeekResponse2\270\013\n"
+ + "\tPublisher\022q\n\013CreateTopic\022\027.google.pubsu"
+ + "b.v1.Topic\032\027.google.pubsub.v1.Topic\"0\332A\004"
+ + "name\202\323\344\223\002#\032\036/v1/{name=projects/*/topics/"
+ + "*}:\001*\022\221\001\n\013UpdateTopic\022$.google.pubsub.v1"
+ + ".UpdateTopicRequest\032\027.google.pubsub.v1.T"
+ + "opic\"C\332A\021topic,update_mask\202\323\344\223\002)2$/v1/{t"
+ + "opic.name=projects/*/topics/*}:\001*\022\223\001\n\007Pu"
+ + "blish\022 .google.pubsub.v1.PublishRequest\032"
+ + "!.google.pubsub.v1.PublishResponse\"C\332A\016t"
+ + "opic,messages\202\323\344\223\002,\"\'/v1/{topic=projects"
+ + "/*/topics/*}:publish:\001*\022w\n\010GetTopic\022!.go"
+ + "ogle.pubsub.v1.GetTopicRequest\032\027.google."
+ + "pubsub.v1.Topic\"/\332A\005topic\202\323\344\223\002!\022\037/v1/{to"
+ + "pic=projects/*/topics/*}\022\212\001\n\nListTopics\022"
+ + "#.google.pubsub.v1.ListTopicsRequest\032$.g"
+ + "oogle.pubsub.v1.ListTopicsResponse\"1\332A\007p"
+ + "roject\202\323\344\223\002!\022\037/v1/{project=projects/*}/t"
+ + "opics\022\272\001\n\026ListTopicSubscriptions\022/.googl"
+ + "e.pubsub.v1.ListTopicSubscriptionsReques"
+ + "t\0320.google.pubsub.v1.ListTopicSubscripti"
+ + "onsResponse\"=\332A\005topic\202\323\344\223\002/\022-/v1/{topic="
+ + "projects/*/topics/*}/subscriptions\022\252\001\n\022L"
+ + "istTopicSnapshots\022+.google.pubsub.v1.Lis"
+ + "tTopicSnapshotsRequest\032,.google.pubsub.v"
+ + "1.ListTopicSnapshotsResponse\"9\332A\005topic\202\323"
+ + "\344\223\002+\022)/v1/{topic=projects/*/topics/*}/sn"
+ + "apshots\022|\n\013DeleteTopic\022$.google.pubsub.v"
+ + "1.DeleteTopicRequest\032\026.google.protobuf.E"
+ + "mpty\"/\332A\005topic\202\323\344\223\002!*\037/v1/{topic=project"
+ + "s/*/topics/*}\022\255\001\n\022DetachSubscription\022+.g"
+ + "oogle.pubsub.v1.DetachSubscriptionReques"
+ + "t\032,.google.pubsub.v1.DetachSubscriptionR"
+ + "esponse\"<\202\323\344\223\0026\"4/v1/{subscription=proje"
+ + "cts/*/subscriptions/*}:detach\032p\312A\025pubsub"
+ + ".googleapis.com\322AUhttps://www.googleapis"
+ + ".com/auth/cloud-platform,https://www.goo"
+ + "gleapis.com/auth/pubsub2\322\025\n\nSubscriber\022\264"
+ + "\001\n\022CreateSubscription\022\036.google.pubsub.v1"
+ + ".Subscription\032\036.google.pubsub.v1.Subscri"
+ + "ption\"^\332A+name,topic,push_config,ack_dea"
+ + "dline_seconds\202\323\344\223\002*\032%/v1/{name=projects/"
+ + "*/subscriptions/*}:\001*\022\241\001\n\017GetSubscriptio"
+ + "n\022(.google.pubsub.v1.GetSubscriptionRequ"
+ + "est\032\036.google.pubsub.v1.Subscription\"D\332A\014"
+ + "subscription\202\323\344\223\002/\022-/v1/{subscription=pr"
+ + "ojects/*/subscriptions/*}\022\273\001\n\022UpdateSubs"
+ + "cription\022+.google.pubsub.v1.UpdateSubscr"
+ + "iptionRequest\032\036.google.pubsub.v1.Subscri"
+ + "ption\"X\332A\030subscription,update_mask\202\323\344\223\0027"
+ + "22/v1/{subscription.name=projects/*/subs"
+ + "criptions/*}:\001*\022\246\001\n\021ListSubscriptions\022*."
+ + "google.pubsub.v1.ListSubscriptionsReques"
+ + "t\032+.google.pubsub.v1.ListSubscriptionsRe"
+ + "sponse\"8\332A\007project\202\323\344\223\002(\022&/v1/{project=p"
+ + "rojects/*}/subscriptions\022\237\001\n\022DeleteSubsc"
+ + "ription\022+.google.pubsub.v1.DeleteSubscri"
+ + "ptionRequest\032\026.google.protobuf.Empty\"D\332A"
+ + "\014subscription\202\323\344\223\002/*-/v1/{subscription=p"
+ + "rojects/*/subscriptions/*}\022\317\001\n\021ModifyAck"
+ + "Deadline\022*.google.pubsub.v1.ModifyAckDea"
+ + "dlineRequest\032\026.google.protobuf.Empty\"v\332A"
+ + ")subscription,ack_ids,ack_deadline_secon"
+ + "ds\202\323\344\223\002D\"?/v1/{subscription=projects/*/s"
+ + "ubscriptions/*}:modifyAckDeadline:\001*\022\250\001\n"
+ + "\013Acknowledge\022$.google.pubsub.v1.Acknowle"
+ + "dgeRequest\032\026.google.protobuf.Empty\"[\332A\024s"
+ + "ubscription,ack_ids\202\323\344\223\002>\"9/v1/{subscrip"
+ + "tion=projects/*/subscriptions/*}:acknowl"
+ + "edge:\001*\022\320\001\n\004Pull\022\035.google.pubsub.v1.Pull"
+ + "Request\032\036.google.pubsub.v1.PullResponse\""
+ + "\210\001\332A,subscription,return_immediately,max"
+ + "_messages\332A\031subscription,max_messages\202\323\344"
+ + "\223\0027\"2/v1/{subscription=projects/*/subscr"
+ + "iptions/*}:pull:\001*\022f\n\rStreamingPull\022&.go"
+ + "ogle.pubsub.v1.StreamingPullRequest\032\'.go"
+ + "ogle.pubsub.v1.StreamingPullResponse\"\000(\001"
+ + "0\001\022\273\001\n\020ModifyPushConfig\022).google.pubsub."
+ + "v1.ModifyPushConfigRequest\032\026.google.prot"
+ + "obuf.Empty\"d\332A\030subscription,push_config\202"
+ + "\323\344\223\002C\">/v1/{subscription=projects/*/subs"
+ + "criptions/*}:modifyPushConfig:\001*\022\211\001\n\013Get"
+ + "Snapshot\022$.google.pubsub.v1.GetSnapshotR"
+ + "equest\032\032.google.pubsub.v1.Snapshot\"8\332A\010s"
+ + "napshot\202\323\344\223\002\'\022%/v1/{snapshot=projects/*/"
+ + "snapshots/*}\022\226\001\n\rListSnapshots\022&.google."
+ + "pubsub.v1.ListSnapshotsRequest\032\'.google."
+ + "pubsub.v1.ListSnapshotsResponse\"4\332A\007proj"
+ + "ect\202\323\344\223\002$\022\"/v1/{project=projects/*}/snap"
+ + "shots\022\227\001\n\016CreateSnapshot\022\'.google.pubsub"
+ + ".v1.CreateSnapshotRequest\032\032.google.pubsu"
+ + "b.v1.Snapshot\"@\332A\021name,subscription\202\323\344\223\002"
+ + "&\032!/v1/{name=projects/*/snapshots/*}:\001*\022"
+ + "\243\001\n\016UpdateSnapshot\022\'.google.pubsub.v1.Up"
+ + "dateSnapshotRequest\032\032.google.pubsub.v1.S"
+ + "napshot\"L\332A\024snapshot,update_mask\202\323\344\223\002/2*"
+ + "/v1/{snapshot.name=projects/*/snapshots/"
+ + "*}:\001*\022\213\001\n\016DeleteSnapshot\022\'.google.pubsub"
+ + ".v1.DeleteSnapshotRequest\032\026.google.proto"
+ + "buf.Empty\"8\332A\010snapshot\202\323\344\223\002\'*%/v1/{snaps"
+ + "hot=projects/*/snapshots/*}\022\204\001\n\004Seek\022\035.g"
+ + "oogle.pubsub.v1.SeekRequest\032\036.google.pub"
+ + "sub.v1.SeekResponse\"=\202\323\344\223\0027\"2/v1/{subscr"
+ + "iption=projects/*/subscriptions/*}:seek:"
+ + "\001*\032p\312A\025pubsub.googleapis.com\322AUhttps://w"
+ + "ww.googleapis.com/auth/cloud-platform,ht"
+ + "tps://www.googleapis.com/auth/pubsubB\252\001\n"
+ + "\024com.google.pubsub.v1B\013PubsubProtoP\001Z2cl"
+ + "oud.google.com/go/pubsub/apiv1/pubsubpb;"
+ + "pubsubpb\370\001\001\252\002\026Google.Cloud.PubSub.V1\312\002\026G"
+ + "oogle\\Cloud\\PubSub\\V1\352\002\031Google::Cloud::P"
+ + "ubSub::V1b\006proto3"
};
descriptor =
com.google.protobuf.Descriptors.FileDescriptor.internalBuildGeneratedFileFrom(
@@ -884,7 +885,12 @@ public static com.google.protobuf.Descriptors.FileDescriptor getDescriptor() {
new com.google.protobuf.GeneratedMessageV3.FieldAccessorTable(
internal_static_google_pubsub_v1_BigQueryConfig_descriptor,
new java.lang.String[] {
- "Table", "UseTopicSchema", "WriteMetadata", "DropUnknownFields", "State",
+ "Table",
+ "UseTopicSchema",
+ "WriteMetadata",
+ "DropUnknownFields",
+ "State",
+ "UseTableSchema",
});
internal_static_google_pubsub_v1_CloudStorageConfig_descriptor =
getDescriptor().getMessageTypes().get(23);
diff --git a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PullRequest.java b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PullRequest.java
index fac062007..30c5431b8 100644
--- a/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PullRequest.java
+++ b/proto-google-cloud-pubsub-v1/src/main/java/com/google/pubsub/v1/PullRequest.java
@@ -136,7 +136,7 @@ public com.google.protobuf.ByteString getSubscriptionBytes() {
*
diff --git a/proto-google-cloud-pubsub-v1/src/main/proto/google/pubsub/v1/pubsub.proto b/proto-google-cloud-pubsub-v1/src/main/proto/google/pubsub/v1/pubsub.proto
index 9ff80f2f6..393893b10 100644
--- a/proto-google-cloud-pubsub-v1/src/main/proto/google/pubsub/v1/pubsub.proto
+++ b/proto-google-cloud-pubsub-v1/src/main/proto/google/pubsub/v1/pubsub.proto
@@ -44,7 +44,7 @@ service Publisher {
"https://www.googleapis.com/auth/pubsub";
// Creates the given topic with the given name. See the [resource name rules]
- // (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ // (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
rpc CreateTopic(Topic) returns (Topic) {
option (google.api.http) = {
put: "/v1/{name=projects/*/topics/*}"
@@ -137,11 +137,12 @@ service Publisher {
// A policy constraining the storage of messages published to the topic.
message MessageStoragePolicy {
// A list of IDs of GCP regions where messages that are published to the topic
// may be persisted in storage. Messages published by publishers running in
// non-allowed GCP regions (or running outside of GCP altogether) will be
// routed for storage in one of the allowed regions. An empty list means that
// no regions are allowed, and is not a valid configuration.
repeated string allowed_persistence_regions = 1;
}
@@ -430,16 +431,16 @@ service Subscriber {
"https://www.googleapis.com/auth/pubsub";
// Creates a subscription to a given topic. See the [resource name rules]
- // (https://cloud.google.com/pubsub/docs/admin#resource_names).
+ // (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
// If the subscription already exists, returns `ALREADY_EXISTS`.
// If the corresponding topic doesn't exist, returns `NOT_FOUND`.
//
// If the name is not provided in the request, the server will assign a random
// name for this subscription on the same project as the topic, conforming
// to the [resource name format]
- // (https://cloud.google.com/pubsub/docs/admin#resource_names). The generated
- // name is populated in the returned Subscription object. Note that for REST
- // API requests, you must specify a name in the request.
+ // (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The
+ // generated name is populated in the returned Subscription object. Note that
+ // for REST API requests, you must specify a name in the request.
rpc CreateSubscription(Subscription) returns (Subscription) {
option (google.api.http) = {
put: "/v1/{name=projects/*/subscriptions/*}"
@@ -592,7 +593,7 @@ service Subscriber {
// the request, the server will assign a random
// name for this snapshot on the same project as the subscription, conforming
// to the [resource name format]
- // (https://cloud.google.com/pubsub/docs/admin#resource_names). The
+ // (https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names). The
// generated name is populated in the returned Snapshot object. Note that for
// REST API requests, you must specify a name in the request.
rpc CreateSnapshot(CreateSnapshotRequest) returns (Snapshot) {
@@ -996,9 +997,10 @@ message BigQueryConfig {
// {projectId}.{datasetId}.{tableId}
string table = 1;
- // When true, use the topic's schema as the columns to write to in BigQuery,
- // if it exists.
- bool use_topic_schema = 2;
+ // Optional. When true, use the topic's schema as the columns to write to in
+ // BigQuery, if it exists. `use_topic_schema` and `use_table_schema` cannot be
+ // enabled at the same time.
+ bool use_topic_schema = 2 [(google.api.field_behavior) = OPTIONAL];
// When true, write the subscription name, message_id, publish_time,
// attributes, and ordering_key to additional columns in the table. The
@@ -1017,6 +1019,11 @@ message BigQueryConfig {
// Output only. An output-only field that indicates whether or not the
// subscription can receive messages.
State state = 5 [(google.api.field_behavior) = OUTPUT_ONLY];
+
+ // Optional. When true, use the BigQuery table's schema as the columns to
+ // write to in BigQuery. `use_table_schema` and `use_topic_schema` cannot be
+ // enabled at the same time.
+ bool use_table_schema = 6 [(google.api.field_behavior) = OPTIONAL];
}
// Configuration for a Cloud Storage subscription.
@@ -1030,7 +1037,11 @@ message CloudStorageConfig {
// Message payloads and metadata will be written to files as an Avro binary.
message AvroConfig {
// When true, write the subscription name, message_id, publish_time,
- // attributes, and ordering_key as additional fields in the output.
+ // attributes, and ordering_key as additional fields in the output. The
+ // subscription name, message_id, and publish_time fields are put in their
+ // own fields while all other message properties other than data (for
+ // example, an ordering_key, if present) are added as entries in the
+ // attributes map.
bool write_metadata = 1;
}
@@ -1425,8 +1436,8 @@ message CreateSnapshotRequest {
// in the request, the server will assign a random name for this snapshot on
// the same project as the subscription. Note that for REST API requests, you
// must specify a name. See the [resource name
- // rules](https://cloud.google.com/pubsub/docs/admin#resource_names). Format
- // is `projects/{project}/snapshots/{snap}`.
+ // rules](https://cloud.google.com/pubsub/docs/pubsub-basics#resource_names).
+ // Format is `projects/{project}/snapshots/{snap}`.
string name = 1 [
(google.api.field_behavior) = REQUIRED,
(google.api.resource_reference) = { type: "pubsub.googleapis.com/Snapshot" }
@@ -137,11 +137,12 @@ service Publisher {
// A policy constraining the storage of messages published to the topic.
message MessageStoragePolicy {
- // A list of IDs of GCP regions where messages that are published to the topic
- // may be persisted in storage. Messages published by publishers running in
- // non-allowed GCP regions (or running outside of GCP altogether) will be
- // routed for storage in one of the allowed regions. An empty list means that
- // no regions are allowed, and is not a valid configuration.
+ // A list of IDs of Google Cloud regions where messages that are published
+ // to the topic may be persisted in storage. Messages published by publishers
+ // running in non-allowed Google Cloud regions (or running outside of Google
+ // Cloud altogether) are routed for storage in one of the allowed regions.
+ // An empty list means that no regions are allowed, and is not a valid
+ // configuration.
repeated string allowed_persistence_regions = 1;
}